.. comp_chem_py documentation master file, created by
   sphinx-quickstart on Fri Sep 14 11:43:19 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

comp_chem_py: python library for computational chemistry
========================================================

Most of the documentation here is automatically generated
from docstrings in the source code and README.rst files
present in the different directories of the package.

Contents:

.. toctree::
   :maxdepth: 2

   comp_chem_utils
   PDOS

.. include:: ../README.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

